==> miro_4.0.4.orig.tar.gz: miro-4.0.4/windows/plat/frontends/widgets/XULRunnerBrowser/MiroDirectoryProvider.cpp <==
/*
# Miro - an RSS based video player application
# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
# Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.
*/

#include "MiroDirectoryProvider.h"
#include "nsXPCOMCID.h"
#include "nsILocalFile.h"
#include "nsIDirectoryService.h"
#include "nsAppDirectoryServiceDefs.h"
#include "xulapp/nsXULAppAPI.h"
#include "xpcom/nsServiceManagerUtils.h"

NS_IMPL_ISUPPORTS1(MiroDirectoryProvider, nsIDirectoryServiceProvider)

MiroDirectoryProvider::MiroDirectoryProvider()
{
}

MiroDirectoryProvider::~MiroDirectoryProvider()
{
}

nsresult MiroDirectoryProvider::install(const char* dir)
{
    nsresult rv;
    rv = NS_NewNativeLocalFile(nsEmbedCString(dir), PR_FALSE, &mProfileDir);
    NS_ENSURE_SUCCESS(rv, rv);
    nsCOMPtr<nsIDirectoryService> directory_service(
                do_GetService(NS_DIRECTORY_SERVICE_CONTRACTID, &rv));
    NS_ENSURE_SUCCESS(rv, rv);

    rv = directory_service->RegisterProvider(this);
    NS_ENSURE_SUCCESS(rv, rv);
    return NS_OK;
}

NS_IMETHODIMP MiroDirectoryProvider::GetFile(const char *aKey,
					     PRBool *aPersist,
					     nsIFile* *aResult)
{
  if (!strcmp(aKey, NS_APP_USER_PROFILE_50_DIR) ||
      !strcmp(aKey, NS_APP_PROFILE_DIR_STARTUP)) {
    *aPersist = PR_TRUE;
    return mProfileDir->Clone(aResult);
  }
  return NS_ERROR_FAILURE;
}

==> miro-6.0.tar.gz: miro-6.0/windows/plat/frontends/widgets/XULRunnerBrowser/MiroDirectoryProvider.cpp <==
/*
# Miro - an RSS based video player application
# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
# Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.
*/

#include "MiroDirectoryProvider.h"
#include "nsXPCOMCID.h"
#include "nsILocalFile.h"
#include "nsIDirectoryService.h"
#include "nsAppDirectoryServiceDefs.h"
#include "nsXULAppAPI.h"
#include "nsServiceManagerUtils.h"

NS_IMPL_ISUPPORTS1(MiroDirectoryProvider, nsIDirectoryServiceProvider)

MiroDirectoryProvider::MiroDirectoryProvider()
{
}

MiroDirectoryProvider::~MiroDirectoryProvider()
{
}

nsresult MiroDirectoryProvider::install(const char* dir)
{
    nsresult rv;
    rv = NS_NewNativeLocalFile(nsEmbedCString(dir), PR_FALSE, &mProfileDir);
    NS_ENSURE_SUCCESS(rv, rv);
    nsCOMPtr<nsIDirectoryService> directory_service(
                do_GetService(NS_DIRECTORY_SERVICE_CONTRACTID, &rv));
    NS_ENSURE_SUCCESS(rv, rv);

    rv = directory_service->RegisterProvider(this);
    NS_ENSURE_SUCCESS(rv, rv);
    return NS_OK;
}

NS_IMETHODIMP MiroDirectoryProvider::GetFile(const char *aKey,
					     PRBool *aPersist,
					     nsIFile* *aResult)
{
  if (!strcmp(aKey, NS_APP_USER_PROFILE_50_DIR) ||
      !strcmp(aKey, NS_APP_PROFILE_DIR_STARTUP)) {
    *aPersist = PR_TRUE;
    return mProfileDir->Clone(aResult);
  }
  return NS_ERROR_FAILURE;
}
